@@ -6,7 +6,7 @@ import os,sys
 
 debug = False
 if os.path.exists("./debug"):
-    sys.path.insert(os.path.abspath("../"))
+    sys.path.insert(os.path.abspath("./"))
     debug = True
 
 from IutyScripts.coding.publisher import main as client
@@ -15,6 +15,10 @@ from IutyScripts.coding.publisher import main as client
 function below
 --------------------------
 """
+def getHelp():
+    
+
+
 def getArg():
     arg = None
     if len(sys.argv) > 1:
